==> otu-5000-16.94.tar: acterna/release/smartotu/app/view/SMTAppLayout.php <==
<!DOCTYPE html>
<html>
<head>
<!-- GWT integration -->
<meta name="gwt:property" content="locale=<?php echo $currentLanguage ?>"/>
<meta http-equiv="X-UA-Compatible" content="IE=10" />
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<link rel="icon" type="image/ico" href="app/view/images/favicon.ico" />
<link rel="stylesheet" type="text/css" href="app/view/stylesheets/App.css" />

<script type="text/javascript" src="lib/crypto2.js"></script>
<script type="text/javascript" src="client/com.smartotu.SmartOtu.nocache.js"></script>


<script type="text/javascript">
var SmartApp = {
		  mode:"<?php echo $smartMode ?>"
		};
function cleanup()
{
        var loginDiv = document.getElementById ( "TPZLoginHeaderId" );
        loginDiv.parentNode.removeChild( loginDiv );

        var loginDiv = document.getElementById ( "TPZLoginPanelId" );
        loginDiv.parentNode.removeChild( loginDiv );

        var loginDiv = document.getElementById ( "TPZLoginFooterId" );
        loginDiv.parentNode.removeChild( loginDiv );
}        
</script>
<title><?php echo $productName ?></title>

<style id="anti_click_jack">body{display:none !anticlick;}</style>
<script type="text/javascript">
   if (self === top) {
       var antiClickjack = document.getElementById("anti_click_jack");
       antiClickjack.parentNode.removeChild(antiClickjack);
   } else {
       top.location = self.location;
   }
</script>
</head>
<body onload="cleanup()">
    <?php include "background.php" ?>
    <div id="TPZLoginPanelId" class="TPZLoginPanel">
	    <div class="TPZSplashScreen">
		    <div class="TPZMessages">
	    	    <?php echo MSG_SPLASH_SCREEN_MESSAGE ?>
		    </div>
		    <div><img src="/app/view/images/wait_35x35.gif" /></div>
		</div>
		<div id="messagesId" class="TPZLoginPanelMessages">
		    <noscript>
		    <div class="TPZErrorMessages"><?php echo MSG_NO_JS ?></div>
		    </noscript>
        </div>
        <script type="text/javascript">
        // <![CDATA[
        // Due to a problem on ie8, we need to remove the noscript element.
        // This method is inline to be removed later once GWT module is loaded.
        var messagesDiv = document.getElementById ( "messagesId" );
   		var noscript = messagesDiv.getElementsByTagName ( "noscript" );
        for ( var i = 0; i < noscript.length; i++ )
        {
            messagesDiv.removeChild ( noscript[i] );
        }        
        // ]]>
        </script>
    </div>
    <?php include "footer.php"?>
    

    <!-- GWT integration -->
    <iframe src="javascript:''" id="__gwt_historyFrame" tabIndex='-1' style="position: absolute; width: 0; height: 0; border: 0" />
</body>
</html>

==> otu-5000-18.80.tar: acterna/release/smartotu/app/view/SMTAppLayout.php <==
<!DOCTYPE html>
<html>
<head>
<!-- GWT integration -->
<meta name="gwt:property" content="locale=<?php echo $currentLanguage ?>"/>
<meta http-equiv="X-UA-Compatible" content="IE=10" />
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<link rel="icon" type="image/ico" href="app/view/images/favicon.ico" />
<link rel="stylesheet" type="text/css" href="app/view/stylesheets/App.css" />

<script type="text/javascript" src="lib/crypto2.js"></script>
<script type="text/javascript" src="client/com.smartotu.SmartOtu.nocache.js"></script>


<script type="text/javascript">
var SmartApp = {
		  mode:"<?php echo $smartMode ?>",
	      option:"<?php echo $smartOption ?>",
	      license:"<?php echo $martLicences ?>"
		};
function cleanup()
{
        var loginDiv = document.getElementById ( "TPZLoginHeaderId" );
        loginDiv.parentNode.removeChild( loginDiv );

        var loginDiv = document.getElementById ( "TPZLoginPanelId" );
        loginDiv.parentNode.removeChild( loginDiv );

        var loginDiv = document.getElementById ( "TPZLoginFooterId" );
        loginDiv.parentNode.removeChild( loginDiv );
}        
</script>
<title><?php echo $productName ?></title>

<style id="anti_click_jack">body{display:none !anticlick;}</style>
<script type="text/javascript">
   if (self === top) {
       var antiClickjack = document.getElementById("anti_click_jack");
       antiClickjack.parentNode.removeChild(antiClickjack);
   } else {
       top.location = self.location;
   }
</script>
</head>
<body onload="cleanup()">
    <?php include "background.php" ?>
    <div id="TPZLoginPanelId" class="TPZLoginPanel">
	    <div class="TPZSplashScreen">
		    <div class="TPZMessages">
	    	    <?php echo MSG_SPLASH_SCREEN_MESSAGE ?>
		    </div>
		    <div><img src="/app/view/images/wait_35x35.gif" /></div>
		</div>
		<div id="messagesId" class="TPZLoginPanelMessages">
		    <noscript>
		    <div class="TPZErrorMessages"><?php echo MSG_NO_JS ?></div>
		    </noscript>
        </div>
        <script type="text/javascript">
        // <![CDATA[
        // Due to a problem on ie8, we need to remove the noscript element.
        // This method is inline to be removed later once GWT module is loaded.
        var messagesDiv = document.getElementById ( "messagesId" );
   		var noscript = messagesDiv.getElementsByTagName ( "noscript" );
        for ( var i = 0; i < noscript.length; i++ )
        {
            messagesDiv.removeChild ( noscript[i] );
        }        
        // ]]>
        </script>
    </div>
    <?php include "footer.php"?>
    

    <!-- GWT integration -->
    <iframe src="javascript:''" id="__gwt_historyFrame" tabIndex='-1' style="position: absolute; width: 0; height: 0; border: 0" />
</body>
</html>
